Crate wasm_dbms_api

Crate wasm_dbms_api 

WASM DBMS API

Runtime-agnostic API types and traits for the wasm-dbms engine.

This crate provides all shared types, traits, and abstractions needed to interact with a wasm-dbms instance. It is independent of any specific WASM runtime (IC, WASI, Wasmtime, etc.).

Import all useful types and traits via the prelude:

use wasm_dbms_api::prelude::*;

Feature flags

  • candid: Enables CandidType derives on all public types and exposes Candid-specific API boundary types (CandidColumnDef, CandidDataTypeKind).

Modules

dbms
This module contains the main DBMS abstractions and functionalities.
error
memory
prelude
Prelude exposes all public types for the wasm-dbms-api crate.
utils